Documentation
¶
Overview ¶
Package rpcserver provides a JSON RPC to communicate with the client core.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ListCommands ¶
ListCommands prints a short usage string for every route available to the rpcserver.
Types ¶
type Config ¶
type Config struct {
Core clientCore
MarketMaker *mm.MarketMaker
Addr, User, Pass, Cert, Key string
BWVersion *SemVersion
CertHosts []string
}
Config holds variables needed to create a new RPC Server.
type RPCServer ¶
type RPCServer struct {
// contains filtered or unexported fields
}
RPCServer is a single-client http and websocket server enabling a JSON interface to Bison Wallet.
type SemVersion ¶ added in v0.5.0
type SemVersion struct {
VersionString string `json:"versionString"`
Major uint32 `json:"major"`
Minor uint32 `json:"minor"`
Patch uint32 `json:"patch"`
Prerelease string `json:"prerelease,omitempty"`
BuildMetadata string `json:"buildMetadata,omitempty"`
}
SemVersion holds a semver version JSON object.
type VersionResponse ¶ added in v0.5.0
type VersionResponse struct {
RPCServerVer *dex.Semver `json:"rpcServerVersion"`
BWVersion *SemVersion `json:"dexcVersion"`
}
VersionResponse holds bisonw and bisonw rpc server version.
Click to show internal directories.
Click to hide internal directories.