locales

package
v1.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2026 License: BlueOak-1.0.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Ar = map[string]*intl.Translation{}/* 548 elements not displayed */
var DeDE = map[string]*intl.Translation{}/* 670 elements not displayed */
var EnUS = map[string]*intl.Translation{}/* 690 elements not displayed */
var (
	Locales map[string]map[string]*intl.Translation
)
var PlPL = map[string]*intl.Translation{}/* 537 elements not displayed */
var PtBr = map[string]*intl.Translation{}/* 193 elements not displayed */
var ZhCN = map[string]*intl.Translation{}/* 672 elements not displayed */

Functions

func RegisterTranslations added in v1.0.0

func RegisterTranslations()

RegisterTranslations registers translations with the init package for translator worksheet preparation.

func Tokens

func Tokens(tmpl []byte) [][][]byte

Tokens returns a slice of tuples (token, key), where token is just key with triple square brackets, and could also be constructed simply as "[[[" + key + "]]]"". The key is the lookup key for the Locales map. The token is what must be replaced in the raw template.

Types

This section is empty.

Jump to